==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { LegendDescription } from "./LegendDescription";
/**
 * @hidden
 */
export let LegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (LegendDescriptionMetadata.a == null) {
                LegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendDescriptionMetadata.c(LegendDescriptionMetadata.a);
            }
            if (a.k(LegendDescriptionMetadata.a)) {
                return;
            }
            a.aa(LegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            LegendDescriptionMetadata.e(a);
        }
        static d(a) {
            LegendDescriptionMetadata.b(a);
            a.ac("Legend", () => new LegendDescription());
            a.ab("Legend", LegendDescriptionMetadata.a);
        }
    }
    LegendDescriptionMetadata.$t = /*@__PURE__*/ markType(LegendDescriptionMetadata, 'LegendDescriptionMetadata');
    LegendDescriptionMetadata.a = null;
    return LegendDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/LegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { LegendDescription } from "./LegendDescription";
/**
 * @hidden
 */
export let LegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.Legend");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (LegendDescriptionMetadata.a == null) {
                LegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendDescriptionMetadata.c(LegendDescriptionMetadata.a);
            }
            if (a.k(LegendDescriptionMetadata.a)) {
                return;
            }
            a.ac(LegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            LegendDescriptionMetadata.e(a);
        }
        static d(a) {
            LegendDescriptionMetadata.b(a);
            a.ae("Legend", () => new LegendDescription());
            a.ad("Legend", LegendDescriptionMetadata.a);
        }
    }
    LegendDescriptionMetadata.$t = /*@__PURE__*/ markType(LegendDescriptionMetadata, 'LegendDescriptionMetadata');
    LegendDescriptionMetadata.a = null;
    return LegendDescriptionMetadata;
})();
